@@ -16,20 +16,22 @@
 iLO Power Driver
 """
 
-from oslo.config import cfg
-from oslo.utils import importutils
+from oslo_config import cfg
+from oslo_utils import importutils
 
+from ironic.common import boot_devices
 from ironic.common import exception
 from ironic.common.i18n import _
 from ironic.common.i18n import _LE
 from ironic.common import states
 from ironic.conductor import task_manager
+from ironic.conductor import utils as manager_utils
 from ironic.drivers import base
 from ironic.drivers.modules.ilo import common as ilo_common
 from ironic.openstack.common import log as logging
 from ironic.openstack.common import loopingcall
 
-ilo_client = importutils.try_import('proliantutils.ilo.ribcl')
+ilo_error = importutils.try_import('proliantutils.exception')
 
 
 opts = [
@@ -58,10 +60,17 @@ def _attach_boot_iso(task):
     :param task: a TaskManager instance containing the node to act on.
     """
     i_info = task.node.instance_info
+    node_state = task.node.provision_state
 
-    if 'ilo_boot_iso' in i_info:
+    # NOTE: On instance rebuild, ilo_boot_iso will be present in
+    # instance_info but the node will be in DEPLOYING state.
+    # In such a scenario, the ilo_boot_iso shouldn't be
+    # attached to the node while powering on the node (the node
+    # should boot from deploy ramdisk instead, which will already
+    # be attached by the deploy driver).
+    if 'ilo_boot_iso' in i_info and node_state == states.ACTIVE:
         ilo_common.setup_vmedia_for_boot(task, i_info['ilo_boot_iso'])
-        ilo_common.set_boot_device(task.node, 'CDROM')
+        manager_utils.node_set_boot_device(task, boot_devices.CDROM)
 
 
 def _get_power_state(node):
@@ -79,7 +88,7 @@ def _get_power_state(node):
     try:
         power_status = ilo_object.get_host_power_status()
 
-    except ilo_client.IloError as ilo_exception:
+    except ilo_error.IloError as ilo_exception:
         LOG.error(_LE("iLO get_power_state failed for node %(node_id)s with "
                       "error: %(error)s."),
                   {'node_id': node.uuid, 'error': ilo_exception})
@@ -151,7 +160,7 @@ def _set_power_state(task, target_state):
                 "'%s'") % target_state
             raise exception.InvalidParameterValue(msg)
 
-    except ilo_client.IloError as ilo_exception:
+    except ilo_error.IloError as ilo_exception:
         LOG.error(_LE("iLO set_power_state failed to set state to %(tstate)s "
                       " for node %(node_id)s with error: %(error)s"),
                    {'tstate': target_state, 'node_id': node.uuid,
