@@ -85,24 +85,18 @@ class FakeMemcache(object):
 def remove_internal(values, internal):
     # NOTE(yuriyz): internal attributes should not be posted, except uuid
     int_attr = [attr.lstrip('/') for attr in internal if attr != '/uuid']
-    return {k: v for (k, v) in values.items() if k not in int_attr}
+    return dict([(k, v) for (k, v) in values.iteritems() if k not in int_attr])
 
 
 def node_post_data(**kw):
     node = utils.get_test_node(**kw)
-    # These values are not part of the API object
     node.pop('conductor_affinity')
-    node.pop('chassis_id')
-    node.pop('target_raid_config')
-    node.pop('raid_config')
     internal = node_controller.NodePatchType.internal_attrs()
     return remove_internal(node, internal)
 
 
 def port_post_data(**kw):
     port = utils.get_test_port(**kw)
-    # node_id is not part of the API object
-    port.pop('node_id')
     internal = port_controller.PortPatchType.internal_attrs()
     return remove_internal(port, internal)
 
@@ -118,5 +112,6 @@ def post_get_test_node(**kw):
     #                    we have to use chassis_uuid
     node = node_post_data(**kw)
     chassis = utils.get_test_chassis()
+    node['chassis_id'] = None
     node['chassis_uuid'] = kw.get('chassis_uuid', chassis['uuid'])
     return node
