@@ -17,20 +17,21 @@
 
 """Test class for console_utils driver module."""
 
-import mock
 import os
 import random
 import string
 import subprocess
 import tempfile
 
-from oslo.config import cfg
+import mock
+from oslo_concurrency import processutils
+from oslo_config import cfg
+from oslo_utils import netutils
 
 from ironic.common import exception
 from ironic.common import utils
 from ironic.drivers.modules import console_utils
 from ironic.drivers.modules import ipmitool as ipmi
-from ironic.openstack.common import processutils
 from ironic.tests.db import base as db_base
 from ironic.tests.db import utils as db_utils
 from ironic.tests.objects import utils as obj_utils
@@ -184,7 +185,7 @@ class ConsoleUtilsTestCase(db_base.DbTestCase):
         generated_url = console_utils.get_shellinabox_console_url(
                 self.info['port'])
         console_host = CONF.my_ip
-        if utils.is_valid_ipv6(console_host):
+        if netutils.is_valid_ipv6(console_host):
             console_host = '[%s]' % console_host
         http_url = "http://%s:%s" % (console_host, self.info['port'])
         self.assertEqual(generated_url, http_url)
