@@ -19,17 +19,16 @@ import os
 import os.path
 import shutil
 import tempfile
-import uuid
 
 import mock
 import netaddr
-from oslo.config import cfg
+from oslo_concurrency import processutils
+from oslo_config import cfg
 import six
 import six.moves.builtins as __builtin__
 
 from ironic.common import exception
 from ironic.common import utils
-from ironic.openstack.common import processutils
 from ironic.tests import base
 
 CONF = cfg.CONF
@@ -44,25 +43,25 @@ class BareMetalUtilsTestCase(base.TestCase):
         self.assertEqual(100, len(s))
 
     def test_unlink(self):
-        with mock.patch.object(os, "unlink") as unlink_mock:
+        with mock.patch.object(os, "unlink", autospec=True) as unlink_mock:
             unlink_mock.return_value = None
             utils.unlink_without_raise("/fake/path")
             unlink_mock.assert_called_once_with("/fake/path")
 
     def test_unlink_ENOENT(self):
-        with mock.patch.object(os, "unlink") as unlink_mock:
+        with mock.patch.object(os, "unlink", autospec=True) as unlink_mock:
             unlink_mock.side_effect = OSError(errno.ENOENT)
             utils.unlink_without_raise("/fake/path")
             unlink_mock.assert_called_once_with("/fake/path")
 
     def test_create_link(self):
-        with mock.patch.object(os, "symlink") as symlink_mock:
+        with mock.patch.object(os, "symlink", autospec=True) as symlink_mock:
             symlink_mock.return_value = None
             utils.create_link_without_raise("/fake/source", "/fake/link")
             symlink_mock.assert_called_once_with("/fake/source", "/fake/link")
 
     def test_create_link_EEXIST(self):
-        with mock.patch.object(os, "symlink") as symlink_mock:
+        with mock.patch.object(os, "symlink", autospec=True) as symlink_mock:
             symlink_mock.side_effect = OSError(errno.EEXIST)
             utils.create_link_without_raise("/fake/source", "/fake/link")
             symlink_mock.assert_called_once_with("/fake/source", "/fake/link")
@@ -97,11 +96,18 @@ exit 1
 ''')
             fp.close()
             os.chmod(tmpfilename, 0o755)
-            self.assertRaises(processutils.ProcessExecutionError,
-                              utils.execute,
-                              tmpfilename, tmpfilename2, attempts=10,
-                              process_input='foo',
-                              delay_on_retry=False)
+            try:
+                self.assertRaises(processutils.ProcessExecutionError,
+                                  utils.execute,
+                                  tmpfilename, tmpfilename2, attempts=10,
+                                  process_input='foo',
+                                  delay_on_retry=False)
+            except OSError as e:
+                if e.errno == errno.EACCES:
+                    self.skipTest("Permissions error detected. "
+                                  "Are you running with a noexec /tmp?")
+                else:
+                    raise
             fp = open(tmpfilename2, 'r')
             runs = fp.read()
             fp.close()
@@ -142,23 +148,30 @@ grep foo
 ''')
             fp.close()
             os.chmod(tmpfilename, 0o755)
-            utils.execute(tmpfilename,
-                          tmpfilename2,
-                          process_input='foo',
-                          attempts=2)
+            try:
+                utils.execute(tmpfilename,
+                              tmpfilename2,
+                              process_input='foo',
+                              attempts=2)
+            except OSError as e:
+                if e.errno == errno.EACCES:
+                    self.skipTest("Permissions error detected. "
+                                  "Are you running with a noexec /tmp?")
+                else:
+                    raise
         finally:
             os.unlink(tmpfilename)
             os.unlink(tmpfilename2)
 
-    @mock.patch.object(processutils, 'execute')
-    @mock.patch.object(os.environ, 'copy', return_value={})
+    @mock.patch.object(processutils, 'execute', autospec=True)
+    @mock.patch.object(os.environ, 'copy', return_value={}, autospec=True)
     def test_execute_use_standard_locale_no_env_variables(self, env_mock,
                                                           execute_mock):
         utils.execute('foo', use_standard_locale=True)
         execute_mock.assert_called_once_with('foo',
                                              env_variables={'LC_ALL': 'C'})
 
-    @mock.patch.object(processutils, 'execute')
+    @mock.patch.object(processutils, 'execute', autospec=True)
     def test_execute_use_standard_locale_with_env_variables(self,
                                                             execute_mock):
         utils.execute('foo', use_standard_locale=True,
@@ -167,7 +180,7 @@ grep foo
                                              env_variables={'LC_ALL': 'C',
                                                             'foo': 'bar'})
 
-    @mock.patch.object(processutils, 'execute')
+    @mock.patch.object(processutils, 'execute', autospec=True)
     def test_execute_not_use_standard_locale(self, execute_mock):
         utils.execute('foo', use_standard_locale=False,
                       env_variables={'foo': 'bar'})
@@ -175,14 +188,16 @@ grep foo
                                              env_variables={'foo': 'bar'})
 
     def test_execute_get_root_helper(self):
-        with mock.patch.object(processutils, 'execute') as execute_mock:
+        with mock.patch.object(
+                processutils, 'execute', autospec=True) as execute_mock:
             helper = utils._get_root_helper()
             utils.execute('foo', run_as_root=True)
             execute_mock.assert_called_once_with('foo', run_as_root=True,
                                                  root_helper=helper)
 
     def test_execute_without_root_helper(self):
-        with mock.patch.object(processutils, 'execute') as execute_mock:
+        with mock.patch.object(
+                processutils, 'execute', autospec=True) as execute_mock:
             utils.execute('foo', run_as_root=False)
             execute_mock.assert_called_once_with('foo', run_as_root=False)
 
@@ -213,7 +228,8 @@ class GenericUtilsTestCase(base.TestCase):
         self.assertEqual("hello", utils.sanitize_hostname(hostname))
 
     def test_read_cached_file(self):
-        with mock.patch.object(os.path, "getmtime") as getmtime_mock:
+        with mock.patch.object(
+                os.path, "getmtime", autospec=True) as getmtime_mock:
             getmtime_mock.return_value = 1
 
             cache_data = {"data": 1123, "mtime": 1}
@@ -222,8 +238,10 @@ class GenericUtilsTestCase(base.TestCase):
             getmtime_mock.assert_called_once_with(mock.ANY)
 
     def test_read_modified_cached_file(self):
-        with mock.patch.object(os.path, "getmtime") as getmtime_mock:
-            with mock.patch.object(__builtin__, 'open') as open_mock:
+        with mock.patch.object(
+                os.path, "getmtime", autospec=True) as getmtime_mock:
+            with mock.patch.object(
+                    __builtin__, 'open', autospec=True) as open_mock:
                 getmtime_mock.return_value = 2
                 fake_contents = "lorem ipsum"
                 fake_file = mock.Mock()
@@ -274,24 +292,6 @@ class GenericUtilsTestCase(base.TestCase):
         self.assertFalse(utils.is_valid_boolstr('maybe'))
         self.assertFalse(utils.is_valid_boolstr('only on tuesdays'))
 
-    def test_is_valid_ipv4(self):
-        self.assertTrue(utils.is_valid_ipv4('127.0.0.1'))
-        self.assertFalse(utils.is_valid_ipv4('::1'))
-        self.assertFalse(utils.is_valid_ipv4('bacon'))
-        self.assertFalse(utils.is_valid_ipv4(""))
-        self.assertFalse(utils.is_valid_ipv4(10))
-
-    def test_is_valid_ipv6(self):
-        self.assertTrue(utils.is_valid_ipv6("::1"))
-        self.assertTrue(utils.is_valid_ipv6(
-                            "abcd:ef01:2345:6789:abcd:ef01:192.168.254.254"))
-        self.assertTrue(utils.is_valid_ipv6(
-                                    "0000:0000:0000:0000:0000:0000:0000:0001"))
-        self.assertFalse(utils.is_valid_ipv6("foo"))
-        self.assertFalse(utils.is_valid_ipv6("127.0.0.1"))
-        self.assertFalse(utils.is_valid_ipv6(""))
-        self.assertFalse(utils.is_valid_ipv6(10))
-
     def test_is_valid_ipv6_cidr(self):
         self.assertTrue(utils.is_valid_ipv6_cidr("2600::/64"))
         self.assertTrue(utils.is_valid_ipv6_cidr(
@@ -305,8 +305,8 @@ class GenericUtilsTestCase(base.TestCase):
 
     def test_get_shortened_ipv6(self):
         self.assertEqual("abcd:ef01:2345:6789:abcd:ef01:c0a8:fefe",
-                          utils.get_shortened_ipv6(
-                            "abcd:ef01:2345:6789:abcd:ef01:192.168.254.254"))
+                         utils.get_shortened_ipv6(
+                             "abcd:ef01:2345:6789:abcd:ef01:192.168.254.254"))
         self.assertEqual("::1", utils.get_shortened_ipv6(
                                     "0000:0000:0000:0000:0000:0000:0000:0001"))
         self.assertEqual("caca::caca:0:babe:201:102",
@@ -340,15 +340,54 @@ class GenericUtilsTestCase(base.TestCase):
         self.assertFalse(utils.is_valid_mac("AA BB CC DD EE FF"))
         self.assertFalse(utils.is_valid_mac("AA-BB-CC-DD-EE-FF"))
 
+    def test_is_hostname_safe(self):
+        self.assertTrue(utils.is_hostname_safe('spam'))
+        self.assertFalse(utils.is_hostname_safe('spAm'))
+        self.assertFalse(utils.is_hostname_safe('SPAM'))
+        self.assertFalse(utils.is_hostname_safe('-spam'))
+        self.assertFalse(utils.is_hostname_safe('spam-'))
+        self.assertTrue(utils.is_hostname_safe('spam-eggs'))
+        self.assertFalse(utils.is_hostname_safe('spam_eggs'))
+        self.assertFalse(utils.is_hostname_safe('spam eggs'))
+        self.assertTrue(utils.is_hostname_safe('spam.eggs'))
+        self.assertTrue(utils.is_hostname_safe('9spam'))
+        self.assertTrue(utils.is_hostname_safe('spam7'))
+        self.assertTrue(utils.is_hostname_safe('br34kf4st'))
+        self.assertFalse(utils.is_hostname_safe('$pam'))
+        self.assertFalse(utils.is_hostname_safe('egg$'))
+        self.assertFalse(utils.is_hostname_safe('spam#eggs'))
+        self.assertFalse(utils.is_hostname_safe(' eggs'))
+        self.assertFalse(utils.is_hostname_safe('spam '))
+        self.assertTrue(utils.is_hostname_safe('s'))
+        self.assertTrue(utils.is_hostname_safe('s' * 63))
+        self.assertFalse(utils.is_hostname_safe('s' * 64))
+        self.assertFalse(utils.is_hostname_safe(''))
+        self.assertFalse(utils.is_hostname_safe(None))
+        # Need to ensure a binary response for success or fail
+        self.assertIsNotNone(utils.is_hostname_safe('spam'))
+        self.assertIsNotNone(utils.is_hostname_safe('-spam'))
+        self.assertTrue(utils.is_hostname_safe('www.rackspace.com'))
+        self.assertTrue(utils.is_hostname_safe('www.rackspace.com.'))
+        self.assertTrue(utils.is_hostname_safe('http._sctp.www.example.com'))
+        self.assertTrue(utils.is_hostname_safe('mail.pets_r_us.net'))
+        self.assertTrue(utils.is_hostname_safe('mail-server-15.my_host.org'))
+        self.assertFalse(utils.is_hostname_safe('www.nothere.com_'))
+        self.assertFalse(utils.is_hostname_safe('www.nothere_.com'))
+        self.assertFalse(utils.is_hostname_safe('www..nothere.com'))
+        long_str = 'a' * 63 + '.' + 'b' * 63 + '.' + 'c' * 63 + '.' + 'd' * 63
+        self.assertTrue(utils.is_hostname_safe(long_str))
+        self.assertFalse(utils.is_hostname_safe(long_str + '.'))
+        self.assertFalse(utils.is_hostname_safe('a' * 255))
+
     def test_validate_and_normalize_mac(self):
         mac = 'AA:BB:CC:DD:EE:FF'
-        with mock.patch.object(utils, 'is_valid_mac') as m_mock:
+        with mock.patch.object(utils, 'is_valid_mac', autospec=True) as m_mock:
             m_mock.return_value = True
             self.assertEqual(mac.lower(),
                              utils.validate_and_normalize_mac(mac))
 
     def test_validate_and_normalize_mac_invalid_format(self):
-        with mock.patch.object(utils, 'is_valid_mac') as m_mock:
+        with mock.patch.object(utils, 'is_valid_mac', autospec=True) as m_mock:
             m_mock.return_value = False
             self.assertRaises(exception.InvalidMAC,
                               utils.validate_and_normalize_mac, 'invalid-mac')
@@ -373,7 +412,7 @@ class GenericUtilsTestCase(base.TestCase):
 
 class MkfsTestCase(base.TestCase):
 
-    @mock.patch.object(utils, 'execute')
+    @mock.patch.object(utils, 'execute', autospec=True)
     def test_mkfs(self, execute_mock):
         utils.mkfs('ext4', '/my/block/dev')
         utils.mkfs('msdos', '/my/msdos/block/dev')
@@ -390,7 +429,7 @@ class MkfsTestCase(base.TestCase):
                               use_standard_locale=True)]
         self.assertEqual(expected, execute_mock.call_args_list)
 
-    @mock.patch.object(utils, 'execute')
+    @mock.patch.object(utils, 'execute', autospec=True)
     def test_mkfs_with_label(self, execute_mock):
         utils.mkfs('ext4', '/my/block/dev', 'ext4-vol')
         utils.mkfs('msdos', '/my/msdos/block/dev', 'msdos-vol')
@@ -407,14 +446,14 @@ class MkfsTestCase(base.TestCase):
                               use_standard_locale=True)]
         self.assertEqual(expected, execute_mock.call_args_list)
 
-    @mock.patch.object(utils, 'execute',
+    @mock.patch.object(utils, 'execute', autospec=True,
                        side_effect=processutils.ProcessExecutionError(
                            stderr=os.strerror(errno.ENOENT)))
     def test_mkfs_with_unsupported_fs(self, execute_mock):
         self.assertRaises(exception.FileSystemNotSupported,
                           utils.mkfs, 'foo', '/my/block/dev')
 
-    @mock.patch.object(utils, 'execute',
+    @mock.patch.object(utils, 'execute', autospec=True,
                        side_effect=processutils.ProcessExecutionError(
                            stderr='fake'))
     def test_mkfs_with_unexpected_error(self, execute_mock):
@@ -422,46 +461,6 @@ class MkfsTestCase(base.TestCase):
                           'ext4', '/my/block/dev', 'ext4-vol')
 
 
-class IntLikeTestCase(base.TestCase):
-
-    def test_is_int_like(self):
-        self.assertTrue(utils.is_int_like(1))
-        self.assertTrue(utils.is_int_like("1"))
-        self.assertTrue(utils.is_int_like("514"))
-        self.assertTrue(utils.is_int_like("0"))
-
-        self.assertFalse(utils.is_int_like(1.1))
-        self.assertFalse(utils.is_int_like("1.1"))
-        self.assertFalse(utils.is_int_like("1.1.1"))
-        self.assertFalse(utils.is_int_like(None))
-        self.assertFalse(utils.is_int_like("0."))
-        self.assertFalse(utils.is_int_like("aaaaaa"))
-        self.assertFalse(utils.is_int_like("...."))
-        self.assertFalse(utils.is_int_like("1g"))
-        self.assertFalse(
-            utils.is_int_like("0cc3346e-9fef-4445-abe6-5d2b2690ec64"))
-        self.assertFalse(utils.is_int_like("a1"))
-
-
-class UUIDTestCase(base.TestCase):
-
-    def test_generate_uuid(self):
-        uuid_string = utils.generate_uuid()
-        self.assertIsInstance(uuid_string, str)
-        self.assertEqual(36, len(uuid_string))
-        # make sure there are 4 dashes
-        self.assertEqual(32, len(uuid_string.replace('-', '')))
-
-    def test_is_uuid_like(self):
-        self.assertTrue(utils.is_uuid_like(str(uuid.uuid4())))
-
-    def test_id_is_uuid_like(self):
-        self.assertFalse(utils.is_uuid_like(1234567))
-
-    def test_name_is_uuid_like(self):
-        self.assertFalse(utils.is_uuid_like('zhongyueluo'))
-
-
 class TempFilesTestCase(base.TestCase):
 
     def test_tempdir(self):
@@ -472,13 +471,13 @@ class TempFilesTestCase(base.TestCase):
             dirname = tempdir
         self.assertFalse(os.path.exists(dirname))
 
-    @mock.patch.object(shutil, 'rmtree')
-    @mock.patch.object(tempfile, 'mkdtemp')
+    @mock.patch.object(shutil, 'rmtree', autospec=True)
+    @mock.patch.object(tempfile, 'mkdtemp', autospec=True)
     def test_tempdir_mocked(self, mkdtemp_mock, rmtree_mock):
 
         self.config(tempdir='abc')
         mkdtemp_mock.return_value = 'temp-dir'
-        kwargs = {'a': 'b'}
+        kwargs = {'dir': 'b'}
 
         with utils.tempdir(**kwargs) as tempdir:
             self.assertEqual('temp-dir', tempdir)
@@ -487,9 +486,9 @@ class TempFilesTestCase(base.TestCase):
         mkdtemp_mock.assert_called_once_with(**kwargs)
         rmtree_mock.assert_called_once_with(tempdir_created)
 
-    @mock.patch.object(utils, 'LOG')
-    @mock.patch.object(shutil, 'rmtree')
-    @mock.patch.object(tempfile, 'mkdtemp')
+    @mock.patch.object(utils, 'LOG', autospec=True)
+    @mock.patch.object(shutil, 'rmtree', autospec=True)
+    @mock.patch.object(tempfile, 'mkdtemp', autospec=True)
     def test_tempdir_mocked_error_on_rmtree(self, mkdtemp_mock, rmtree_mock,
                                             log_mock):
 
@@ -503,3 +502,14 @@ class TempFilesTestCase(base.TestCase):
 
         rmtree_mock.assert_called_once_with(tempdir_created)
         self.assertTrue(log_mock.error.called)
+
+
+class IsHttpUrlTestCase(base.TestCase):
+
+    def test_is_http_url(self):
+        self.assertTrue(utils.is_http_url('http://127.0.0.1'))
+        self.assertTrue(utils.is_http_url('https://127.0.0.1'))
+        self.assertTrue(utils.is_http_url('HTTP://127.1.2.3'))
+        self.assertTrue(utils.is_http_url('HTTPS://127.3.2.1'))
+        self.assertFalse(utils.is_http_url('Zm9vYmFy'))
+        self.assertFalse(utils.is_http_url('11111111'))
